# Usage example:
#   {% eximaginate photo as image %}
#   {{ image }}
# Note: Eximagination will automatically add "ei_width" and "ei_height" variables to the content - those are the
# original width and height values of the obtained image.

from django import template

from eximagination.conf import get_setting
from eximagination.utils import _obtain_image

register = template.Library()

DEBUG = get_setting('DEBUG') # Set back to settings from DEBUG.
MEDIA_ROOT = get_setting('MEDIA_ROOT')
MEDIA_URL = get_setting('MEDIA_URL')
MEDIA_RELATIVE_ROOT = get_setting('MEDIA_RELATIVE_ROOT')

class EximaginateNode(template.Node):
    def __init__(self, source_var, force_update, context_name):
        self.source_var = template.Variable(source_var)
        self.force_update = bool(force_update)
        self.context_name = context_name

    def render(self, context):
        # Note that this isn't a global constant because we need to change the
        # value for tests.
        try:
            file_data = _obtain_image(image_source=self.source_var.resolve(context),
                                      save_to=MEDIA_ROOT,
                                      media_url=MEDIA_RELATIVE_ROOT,
                                      force_update=self.force_update)
            filename = file_data[0]
            context['ei_width'] = file_data[1] # Original width of the obtained image
            context['ei_height'] = file_data[2] # Original height of the obtained image
            if self.context_name is None:
                return filename

            # We need to get here so we don't have old values in the context
            # variable.
            context[self.context_name] = filename
        except:
            pass

        return ''

@register.tag
def eximaginate(parser, token):
    """
    Copies an external image locally.

    To just output the absolute url to the thumbnail::

        {% eximaginate 'http://www.google.com/intl/en/images/logo.gif' %}

    To put the the downloaded image URL on the context instead of just rendering
    the relative url, finish the tag with ``as [context_var_name]``::

        {% eximaginate 'http://www.google.com/intl/en/images/logo.gif' as original %}

    Eximagination will automatically add "ei_width" and "ei_height" variables to the content - those are the original
    width and height values of the obtained image.

    TODO: Implement force_update feature (some extra tokens parsing)
    """
    arguments = token.split_contents()
    # Check to see if we're setting to a context variable.

    if len(arguments) < 1:
        raise template.TemplateSyntaxError, "%r tag requires at least one argument" % token.contents.split()[0]

    # Get arguments
    if 4 == len(arguments):
        source_var = arguments[1]
        force_update = False # At the moment force_update is not implemented
        context_name = arguments[3]
    elif 2 == len(arguments):
        source_var = arguments[1]
        force_update = False # At the moment force_update is not implemented
        context_name = ''
    else:
        raise template.TemplateSyntaxError, "%r wrong number arguments" % token.contents.split()[0]

    # If the size argument was a correct static format, wrap it in quotes so
    # that it is compiled correctly.
    return EximaginateNode(source_var, force_update, context_name)
